summaryrefslogtreecommitdiff
path: root/common/core/inc/ux_user_sample.h
diff options
context:
space:
mode:
Diffstat (limited to 'common/core/inc/ux_user_sample.h')
-rw-r--r--common/core/inc/ux_user_sample.h34
1 files changed, 28 insertions, 6 deletions
diff --git a/common/core/inc/ux_user_sample.h b/common/core/inc/ux_user_sample.h
index 28a0934..c86531f 100644
--- a/common/core/inc/ux_user_sample.h
+++ b/common/core/inc/ux_user_sample.h
@@ -26,7 +26,7 @@
/* PORT SPECIFIC C INFORMATION RELEASE */
/* */
/* ux_user.h PORTABLE C */
-/* 6.x */
+/* 6.3.0 */
/* */
/* AUTHOR */
/* */
@@ -99,14 +99,15 @@
/* added option to enable */
/* basic USBX error checking, */
/* resulting in version 6.2.1 */
-/* xx-xx-xxxx Xiuwen Cai, CQ Xiao Modified comment(s), */
+/* 10-31-2023 Xiuwen Cai, CQ Xiao Modified comment(s), */
+/* refined memory management, */
/* added zero copy support */
/* in many device classes, */
/* added a new mode to manage */
/* endpoint buffer in classes, */
/* added option for get string */
/* requests with zero wIndex, */
-/* resulting in version 6.x */
+/* resulting in version 6.3.0 */
/* */
/**************************************************************************/
@@ -141,8 +142,8 @@
also refer to ux_port.h for descriptions on each of these options. */
/* Defined, this value represents minimal allocated memory alignment in number of bytes.
- The default is UX_ALIGN_16 (0x0f) to align allocated memory to 16 bytes. */
-/* #define UX_ALIGN_MIN UX_ALIGN_16 */
+ The default is UX_ALIGN_8 (0x07) to align allocated memory to 8 bytes. */
+/* #define UX_ALIGN_MIN UX_ALIGN_8 */
/* Defined, this value represents how many ticks per seconds for a specific hardware platform.
The default is 1000 indicating 1 tick per millisecond. */
@@ -239,7 +240,7 @@
*/
/* #define UX_DEVICE_CLASS_CDC_ACM_ZERO_COPY */
/* Defined, it enables zero copy and flexible queue support (works if HID owns endpoint buffer).
Enabled, the internal queue buffer is directly used for transfer, the APIs are kept to keep
backword compatibility, to AVOID KEEPING BUFFERS IN APPLICATION.
Flexible queue introduces initialization parameter _event_max_number and _event_max_length,
@@ -252,6 +253,27 @@
*/
/* #define UX_DEVICE_CLASS_HID_ZERO_COPY */
+/* Defined, it enables device CDC_ECM zero copy support (works if CDC_ECM owns endpoint buffer).
+ Enabled, it requires that the NX IP default packet pool is in cache safe area, and buffer max
+ size is larger than UX_DEVICE_CLASS_CDC_ECM_ETHERNET_PACKET_SIZE (1536).
+ */
+/* #define UX_DEVICE_CLASS_CDC_ECM_ZERO_COPY */
+
+/* Defined, it enables device RNDIS zero copy support (works if RNDIS owns endpoint buffer).
+ Enabled, it requires that the NX IP default packet pool is in cache safe area, and buffer max
+ size is larger than UX_DEVICE_CLASS_RNDIS_MAX_PACKET_TRANSFER_SIZE (1600).
+ */
+/* #define UX_DEVICE_CLASS_RNDIS_ZERO_COPY */
+
+/* Defined, it enables zero copy support (works if PRINTER owns endpoint buffer).
+ Defined, it enables zero copy for bulk in/out endpoints (write/read). In this case, the endpoint
+ buffer is not allocated in class, application must provide the buffer for read/write, and the
+ buffer must meet device controller driver (DCD) buffer requirements (e.g., aligned and cache
+ safe if buffer is for DMA).
+ */
+/* #define UX_DEVICE_CLASS_PRINTER_ZERO_COPY */
+
+
/* Defined, this value represents the maximum number of bytes that can be received or transmitted
on any endpoint. This value cannot be less than the maximum packet size of any endpoint. The default
is 4096 bytes but can be reduced in memory constrained environments. For cd-rom support in the storage
@@ -239,7 +240,7 @@
*/
/* #define UX_DEVICE_CLASS_CDC_ACM_ZERO_COPY */
-/* Defined, it enables zero copy and flexible queue support (works if HID owns endpoint buffer).
+/* Defined, it enables device HID zero copy and flexible queue support (works if HID owns endpoint buffer).
Enabled, the internal queue buffer is directly used for transfer, the APIs are kept to keep
backword compatibility, to AVOID KEEPING BUFFERS IN APPLICATION.